@@ -48,7 +48,7 @@ from . import ui_settingsdlg  # pylint: disable=no-name-in-module
 # pylint: disable=too-few-public-methods
 class RenameVMThread(common_threads.QubesThread):
     def __init__(self, vm, new_vm_name, dependencies):
-        super(RenameVMThread, self).__init__(vm)
+        super().__init__(vm)
         self.new_vm_name = new_vm_name
         self.dependencies = dependencies
 
@@ -88,7 +88,7 @@ class RenameVMThread(common_threads.QubesThread):
 # pylint: disable=too-few-public-methods
 class RefreshAppsVMThread(common_threads.QubesThread):
     def __init__(self, vm, button):
-        super(RefreshAppsVMThread, self).__init__(vm)
+        super().__init__(vm)
         self.button = button
 
     def run(self):
@@ -129,7 +129,7 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
 
     def __init__(self, vm, init_page="basic", qapp=None, qubesapp=None,
                  parent=None):
-        super(VMSettingsWindow, self).__init__(parent)
+        super().__init__(parent)
 
         self.vm = vm
         self.qapp = qapp
@@ -166,6 +166,7 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
             self.include_in_balancing_changed)
         self.init_mem.editingFinished.connect(self.check_mem_changes)
         self.max_mem_size.editingFinished.connect(self.check_mem_changes)
+        self.check_mem_changes()
         self.boot_from_device_button.clicked.connect(
             self.boot_from_cdrom_button_pressed)
 
@@ -251,7 +252,7 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
         if event.key() == QtCore.Qt.Key_Enter \
                 or event.key() == QtCore.Qt.Key_Return:
             return
-        super(VMSettingsWindow, self).keyPressEvent(event)
+        super().keyPressEvent(event)
 
     def accept(self):
         self.save_and_apply()
@@ -437,6 +438,31 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
         except qubesadmin.exc.QubesDaemonAccessError:
             self.include_in_backups.setEnabled(False)
 
+        try:
+            has_shutdown_idle = self.vm.features.get(
+                "supported-service.shutdown-idle", False)
+            if has_shutdown_idle:
+                self.idle_shutdown_checkbox.setChecked(self.vm.features.get(
+                    "shutdown-idle", False))
+            else:
+                text = "Shut down when idle "
+                if getattr(self.vm, 'template', None):
+                    additional_text = "(unavailable: package " \
+                                      "qubes-app-shutdown-idle missing " \
+                                      "in the template)"
+                else:
+                    additional_text = "(unavailable: package " \
+                                      "qubes-app-shutdown-idle missing " \
+                                      "in the qube)"
+                self.idle_shutdown_checkbox.setText(
+                    text + additional_text)
+            self.idle_shutdown_checkbox.setEnabled(False)
+        except qubesadmin.exc.QubesDaemonCommunicationError:
+            self.idle_shutdown_checkbox.setText(
+                self.idle_shutdown_checkbox.text() +
+                " (unavailable: permission denied)")
+            self.idle_shutdown_checkbox.setEnabled(False)
+
         try:
             self.autostart_vm.setChecked(self.vm.autostart)
             self.autostart_vm.setVisible(True)
@@ -538,6 +564,16 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
         except qubesadmin.exc.QubesException as ex:
             msg.append(str(ex))
 
+        # shutdown-idle
+        try:
+            current_idle = self.vm.features.get("shutdown-idle", False)
+            if self.idle_shutdown_checkbox.isEnabled() and \
+                    self.idle_shutdown_checkbox.isChecked() != current_idle:
+                self.vm.features["shutdown-idle"] = \
+                    self.idle_shutdown_checkbox.isChecked()
+        except qubesadmin.exc.QubesException as ex:
+            msg.append(str(ex))
+
         # max priv storage
         if self.max_priv_storage.isEnabled():
             priv_size = self.max_priv_storage.value()
@@ -561,6 +597,7 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
         return msg
 
     def check_mem_changes(self):
+        self.warn_too_much_mem_label.setVisible(False)
         if not self.include_in_balancing.isChecked():
             # do not interfere with settings if the VM is not included in memory
             # balancing
@@ -586,13 +623,7 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
 
         if is_linux and \
                 self.init_mem.value() * 10 < self.max_mem_size.value():
-            self.init_mem.setValue((self.max_mem_size.value() + 9) // 10)
-            QtWidgets.QMessageBox.warning(
-                self,
-                self.tr("Warning!"),
-                self.tr("For Linux qubes, Initial memory can not be less than "
-                        "one tenth Max memory.<br>Setting initial memory "
-                        "to the minimum allowed value."))
+            self.warn_too_much_mem_label.setVisible(True)
 
     def check_warn_dispvmnetvm(self):
         if not hasattr(self.vm, 'default_dispvm'):
@@ -1096,7 +1127,7 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
         # pylint: disable=too-few-public-methods
         class DevListWidgetItem(QtWidgets.QListWidgetItem):
             def __init__(self, dev, unknown=False, parent=None):
-                super(DevListWidgetItem, self).__init__(parent)
+                super().__init__(parent)
                 name = dev.ident.replace('_', ":") + ' ' + dev.description
                 if unknown:
                     name += ' (unknown)'
@@ -1198,7 +1229,9 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
         self.update_virt_mode_list()
 
     def update_pvh_dont_support_devs(self):
-        if self.virt_mode.currentData() == 'pvh':
+        # this is the easiest way to check for both normal 'PVH' and
+        # default (PVH) options
+        if 'PVH' in self.virt_mode.currentText().upper():
             self.dev_list.setEnabled(False)
             self.pvh_dont_support_devs.setVisible(True)
         else:
