@@ -38,7 +38,8 @@ import qubesmanager.qube_manager as qube_manager
 from qubesmanager.tests import init_qtapp
 
 
-icon_size = QSize(24, 24)
+icon_size = qube_manager.icon_size
+
 
 class QubeManagerTest(unittest.TestCase):
     def setUp(self):
@@ -208,10 +209,9 @@ class QubeManagerTest(unittest.TestCase):
     def test_011_is_label_correct(self):
         for row in range(self.dialog.table.model().rowCount()):
             vm = self._get_table_vm(row)
-            icon = QIcon.fromTheme(vm.label.icon)
+            icon = QIcon.fromTheme(getattr(vm, 'icon', 'appvm-black'))
             icon = icon.pixmap(icon_size)
 
-
             label_pixmap = self._get_table_item(row, "Label", Qt.DecorationRole)
 
             self.assertEqual(label_pixmap.toImage(), icon.toImage())
@@ -309,7 +309,8 @@ class QubeManagerTest(unittest.TestCase):
             selected_vm, qapp=self.qtapp, init_page="applications",
             qubesapp=self.qapp)
 
-    def test_204_vm_keyboard(self):
+    @unittest.mock.patch('PyQt5.QtWidgets.QMessageBox.warning')
+    def test_204_vm_keyboard(self, mock_message):
         selected_vm = self._select_non_admin_vm(running=True)
         self.assertIsNotNone(selected_vm, "No valid non-admin VM found")
         widget = self.dialog.toolbar.widgetForAction(
@@ -318,8 +319,11 @@ class QubeManagerTest(unittest.TestCase):
             QtTest.QTest.mouseClick(widget,
                                     QtCore.Qt.LeftButton)
             mock_run.assert_called_once_with("qubes-change-keyboard-layout")
+        self.assertEqual(mock_message.call_count, 0,
+                         "VM does not support new layout change")
 
-    def test_205_vm_keyboard_not_running(self):
+    @unittest.mock.patch('PyQt5.QtWidgets.QMessageBox.warning')
+    def test_205_vm_keyboard_not_running(self, mock_message):
         selected_vm = self._select_non_admin_vm(running=False)
         self.assertIsNotNone(selected_vm, "No valid non-admin VM found")
         widget = self.dialog.toolbar.widgetForAction(
@@ -329,10 +333,12 @@ class QubeManagerTest(unittest.TestCase):
                                     QtCore.Qt.LeftButton)
             self.assertEqual(mock_run.call_count, 0,
                              "Keyboard change called on a halted VM")
+        self.assertEqual(mock_message.call_count, 0,
+                         "Keyboard change called on a halted VM with"
+                         " obsolete keyboard-layout handling")
 
     def test_206_dom0_keyboard(self):
         self._select_admin_vm()
-
         self.assertFalse(self.dialog.action_set_keyboard_layout.isEnabled())
 
     @unittest.mock.patch("PyQt5.QtWidgets.QMessageBox.question",
@@ -825,7 +831,8 @@ class QubeManagerTest(unittest.TestCase):
         # this requires very long timeout, because it takes time for the
         # dispvm to vanish
         self._run_command_and_process_events(
-            ["qvm-run", "--dispvm", dispvm_template, "true"], timeout=60)
+            ["qvm-run", "--dispvm", dispvm_template, "true"], timeout=60,
+            additional_timeout=60)
 
         final_vms = self._create_set_of_current_vms()
 
@@ -853,7 +860,8 @@ class QubeManagerTest(unittest.TestCase):
             ["qvm-prefs", dispvm_template, "memory", "600000"])
 
         self._run_command_and_process_events(
-            ["qvm-run", "--dispvm", dispvm_template, "true"], timeout=30)
+            ["qvm-run", "--dispvm", dispvm_template, "true"], timeout=30,
+            additional_timeout=15)
 
         final_vms = self._create_set_of_current_vms()
 
@@ -869,7 +877,7 @@ class QubeManagerTest(unittest.TestCase):
         self.addCleanup(
             subprocess.call, ["qvm-prefs", target_vm_name, "label", "blue"])
         self._run_command_and_process_events(
-            ["qvm-prefs", target_vm_name, "label", "red"])
+            ["qvm-prefs", target_vm_name, "label", "red"], timeout=20)
 
         new_label = self._get_table_item(vm_row, "Label", Qt.DecorationRole)
 
@@ -1170,25 +1178,37 @@ class QubeManagerTest(unittest.TestCase):
                 result += 1
         return result
 
-    def _run_command_and_process_events(self, command, timeout=5):
+    def _run_command_and_process_events(self, command, timeout=5,
+                                        additional_timeout=None):
         """
         helper function to run a given command and process eventsDispatcher
         events
         :param command: list of strings, containing the command and all its
         parameters
         :param timeout: default 5 seconds
+        :param additional_timeout: default none
         :return:
         """
         asyncio.set_event_loop(self.loop)
 
         future1 = asyncio.ensure_future(self.dispatcher.listen_for_events())
         self.loop.run_until_complete(asyncio.sleep(0))
+
         future2 = asyncio.create_subprocess_exec(*command,
                                                  stdout=subprocess.DEVNULL,
                                                  stderr=subprocess.DEVNULL)
 
-        (done, pending) = self.loop.run_until_complete(
-            asyncio.wait({future1, future2}, timeout=timeout))
+        future2 = self.loop.run_until_complete(future2).wait()
+
+        if additional_timeout:
+            (done, pending) = self.loop.run_until_complete(
+                asyncio.wait({future1, future2}, timeout=timeout,
+                             return_when=asyncio.FIRST_COMPLETED))
+            (done, pending) = self.loop.run_until_complete(
+                asyncio.wait(pending, timeout=additional_timeout))
+        else:
+            (done, pending) = self.loop.run_until_complete(
+                asyncio.wait({future1, future2}, timeout=timeout))
 
         for task in pending:
             with contextlib.suppress(asyncio.CancelledError):
@@ -1270,11 +1290,12 @@ class QubeManagerTest(unittest.TestCase):
         model = self.dialog.table.model()
         return model.index(row, 0).data(Qt.UserRole).vm
 
-    def _get_table_item(self, row, column_name, role = Qt.DisplayRole):
+    def _get_table_item(self, row, column_name, role=Qt.DisplayRole):
         model = self.dialog.table.model()
         column = self.dialog.qubes_model.columns_indices.index(column_name)
         return model.index(row, column).data(role)
 
+
 class QubeManagerThreadTest(unittest.TestCase):
     def test_01_startvm_thread(self):
         vm = unittest.mock.Mock(spec=['start'])
